TryFromValue

Trait TryFromValue 

pub trait TryFromValue: Sized {
    // Required method
    fn try_from_value(value: &SeaValue) -> Option<Self>;
}
Conversion from a sea-query SeaValue for typed row access.

Required Methods

fn try_from_value(value: &SeaValue) -> Option<Self>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl TryFromValue for Option<String>

Source

impl TryFromValue for String

Source

impl TryFromValue for Value

Source

impl TryFromValue for Vec<u8>

Blob columns. A Database that cannot return bytes cannot hold a ciphertext, a wrapped key or a nonce (issue #39).

Source

impl TryFromValue for bool

Source

impl TryFromValue for f64

Source

impl TryFromValue for i8

Source

impl TryFromValue for i16

Source

impl TryFromValue for i32

Source

impl TryFromValue for i64

Source

impl TryFromValue for u8

Source

impl TryFromValue for u16

Source

impl TryFromValue for u32

Source

impl TryFromValue for u64

Source

impl TryFromValue for usize

Implementors