pub trait TryFromValue: Sized {
// Required method
fn try_from_value(value: &SeaValue) -> Option<Self>;
}Expand description
Conversion from a sea-query SeaValue for typed row access.
Required Methods
fn try_from_value(value: &SeaValue) -> Option<Self>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl TryFromValue for Option<String>
impl TryFromValue for Option<String>
fn try_from_value(value: &SeaValue) -> Option<Self>
Sourceimpl TryFromValue for String
impl TryFromValue for String
fn try_from_value(value: &SeaValue) -> Option<Self>
Sourceimpl TryFromValue for Value
impl TryFromValue for Value
fn try_from_value(value: &SeaValue) -> Option<Self>
Sourceimpl TryFromValue for Vec<u8>
Blob columns. A Database that cannot return bytes cannot hold a
ciphertext, a wrapped key or a nonce (issue #39).
impl TryFromValue for Vec<u8>
Blob columns. A Database that cannot return bytes cannot hold a
ciphertext, a wrapped key or a nonce (issue #39).